﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using System.Collections.Generic;

namespace SilverlightWithUserControls
{
	public class TwoViewModel : ViewModelBase
	{
		private Random r = new Random();
		private List<TemperatureData> _data;

		public TwoViewModel()
		{
			this.FillSampleChartData();
		}

		public List<TemperatureData> Data
		{
			get
			{
				return this._data;
			}
			set
			{
				if (this._data != value)
				{
					this._data = value;
					this.OnPropertyChanged("Data");
				}
			}
		}

		private void FillSampleChartData()
		{
			List<TemperatureData> temperatureData = new List<TemperatureData>();
			DateTime baseDate = new DateTime(2000, 1, 1);

			for (int year = 0; year < 12; year++)
			{
				for (int day = 0; day < 365; day++)
				{
					for (int hour = 0; hour < 24; hour++)
					{
						TemperatureData tempData = new TemperatureData();
						tempData.Temperature = TranslateTemperatureValue(CalculateBaseTemperatureValue(day));
						tempData.Date = baseDate.AddYears(year).AddDays(day).AddHours(hour);
						temperatureData.Add(tempData);
					}
				}
			}

			this.Data = temperatureData;
		}

		private static double CalculateBaseTemperatureValue(int day)
		{
			return Math.Sin(day / 365d * 2 * Math.PI - Math.PI / 2);
		}

		private double TranslateTemperatureValue(double baseTemperatureValue)
		{
			return (baseTemperatureValue + 1) * 20 - 10 + r.Next(-5, 5);
		}
	}

	public class TemperatureData
	{
		private DateTime _date;
		private double _temperature;

		public DateTime Date
		{
			get
			{
				return this._date;
			}
			set
			{
				this._date = value;
			}
		}

		public double Temperature
		{
			get
			{
				return this._temperature;
			}
			set
			{
				this._temperature = value;
			}
		}
	}
}
